<TS language="am" version="2.1">
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Create a new address</source>
        <translation>አዲስ አድራሻ ፍጠር</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;አዲስ</translation>
    </message>
    <message>
        <source>Copy the currently selected address to the system clipboard</source>
        <translation>አሁን የተመረጠውን አድራሻ ወደ ሲስተሙ ቅንጥብ ሰሌዳ ቅዳ</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>&amp;ቅዳ</translation>
    </message>
    <message>
        <source>C&amp;lose</source>
        <translation>ዝጋ</translation>
    </message>
    <message>
        <source>Delete the currently selected address from the list</source>
        <translation>አሁን የተመረጠውን አድራሻ ከዝርዝሩ ውስጥ ሰርዝ</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation>በአሁኑ ማውጫ ውስጥ ያለውን መረጃ ወደ አንድ ፋይል ላክ</translation>
    </message>
    <message>
        <source>&amp;Export</source>
        <translation>&amp;ላክ</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp;ሰርዝ</translation>
    </message>
    <message>
        <source>Choose the address to send coins to</source>
        <translation>ገንዘብ/ኮይኖች የሚልኩለትን አድራሻ ይምረጡ</translation>
    </message>
    <message>
        <source>Choose the address to receive coins with</source>
        <translation>ገንዘብ/ኮይኖች የሚቀበሉበትን አድራሻ ይምረጡ</translation>
    </message>
    <message>
        <source>C&amp;hoose</source>
        <translation>ምረጥ</translation>
    </message>
    <message>
        <source>Sending addresses</source>
        <translation>የመላኪያ አድራሻዎች</translation>
    </message>
    <message>
        <source>Receiving addresses</source>
        <translation>የመቀበያ አድራሻዎች</translation>
    </message>
    <message>
        <source>These are your Bitcoin addresses for sending payments. Always check the amount and the receiving address before sending coins.</source>
        <translation>እነኚ የቢትኮይን ክፍያ የመላኪያ አድራሻዎችዎ ናቸው:: ገንዘብ/ኮይኖች ከመላክዎ በፊት መጠኑን እና የመቀበያ አድራሻውን ሁልጊዜ ያረጋግጡ::</translation>
    </message>
    <message>
        <source>&amp;Copy Address</source>
        <translation>&amp;አድራሻ ቅዳ</translation>
    </message>
    <message>
        <source>Copy &amp;Label</source>
        <translation>ቅዳ &amp;መለያ ስም</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation> &amp;አርም</translation>
    </message>
    <message>
        <source>Export Address List</source>
        <translation>የአድራሻ ዝርዝር ላክ</translation>
    </message>
    <message>
        <source>Comma separated file (*.csv)</source>
        <translation>ኮማ ሴፓሬትድ ፋይል (*.csv)</translation>
    </message>
    <message>
        <source>Exporting Failed</source>
        <translation>ወደ ውጪ መላክ አልተሳካም</translation>
    </message>
    <message>
        <source>There was an error trying to save the address list to %1. Please try again.</source>
        <translation>የአድራሻ ዝርዝሩን ወደ %1 ለማስቀመጥ ሲሞከር ስህተት አጋጥሟል:: እባክዎ መልሰው ይሞክሩ::</translation>
    </message>
</context>
<context>
    <name>AddressTableModel</name>
    <message>
        <source>Label</source>
        <translation>መለያ ስም</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>አድራሻ</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(መለያ ስም የለም)</translation>
    </message>
</context>
<context>
    <name>AskPassphraseDialog</name>
    <message>
        <source>Passphrase Dialog</source>
        <translation>የይለፍ-ሐረግ ንግግር</translation>
    </message>
    <message>
        <source>Enter passphrase</source>
        <translation>የይለፍ-ሐረግዎን ያስገቡ</translation>
    </message>
    <message>
        <source>New passphrase</source>
        <translation>አዲስ የይለፍ-ሐረግ</translation>
    </message>
    <message>
        <source>Repeat new passphrase</source>
        <translation>አዲስ የይለፍ-ሐረጉን ይድገሙት</translation>
    </message>
    <message>
        <source>Encrypt wallet</source>
        <translation>የቢትኮይን ቦርሳውን አመስጥር</translation>
    </message>
    <message>
        <source>This operation needs your wallet passphrase to unlock the wallet.</source>
        <translation>ይህ ክንዋኔ የቢትኮይን ቦርሳዎን ለመክፈት የቦርሳዎ ይለፍ-ሐረግ ያስፈልገዋል::</translation>
    </message>
    <message>
        <source>Unlock wallet</source>
        <translation>የቢትኮይን ቦርሳውን ክፈት</translation>
    </message>
    <message>
        <source>This operation needs your wallet passphrase to decrypt the wallet.</source>
        <translation>ይህ ክንዋኔ የቢትኮይን ቦርሳዎን ለመፍታት የቦርሳዎ ይለፍ-ሐረግ ያስፈልገዋል::</translation>
    </message>
    <message>
        <source>Decrypt wallet</source>
        <translation>የቢትኮይን ቦርሳውን ፍታ</translation>
    </message>
    <message>
        <source>Change passphrase</source>
        <translation>ይለፍ-ሐረግ ለውጥ</translation>
    </message>
    <message>
        <source>Confirm wallet encryption</source>
        <translation>የቢትኮይን ቦርሳዎን ማመስጠር ያረጋግጡ</translation>
    </message>
    <message>
        <source>Warning: If you encrypt your wallet and lose your passphrase, you will &lt;b&gt;LOSE ALL OF YOUR BITCOINS&lt;/b&gt;!</source>
        <translation>ማስጠንቀቂያ: የቢትኮይን ቦርሳዎን አመስጥረው የይለፍ-ሐረግዎን ካጡት&lt;b&gt;ቢትኮይኖቾን በሙሉ ያጣሉ&lt;/b&gt;!</translation>
    </message>
    <message>
        <source>Are you sure you wish to encrypt your wallet?</source>
        <translation>እርግጠኛ ነዎት ቦርሳዎን ማመስጠር ይፈልጋሉ?</translation>
    </message>
    <message>
        <source>Wallet encrypted</source>
        <translation>ቦርሳዎ ምስጢር ተደርጓል</translation>
    </message>
    <message>
        <source>Enter the new passphrase for the wallet.&lt;br/&gt;Please use a passphrase of &lt;b&gt;ten or more random characters&lt;/b&gt;, or &lt;b&gt;eight or more words&lt;/b&gt;.</source>
        <translation>አዲስ የይለፍ ሐረግዎን ወደ ቢትኮይን ቦርሳዎ ያስገቡ:: &lt;br/&gt;እባክዎ ለየይለፍ ሐረግዎ&lt;b&gt;አስር ወይም ከዚያ በላይ የዘፈቀደ ዓይነተ-ፊደላት&lt;/b&gt;, ወይም&lt;b&gt;ስምንት ወይም ከዚያ በላይ ቃላት&lt;/b&gt; ይጠቀሙ ::</translation>
    </message>
    <message>
        <source>Enter the old passphrase and new passphrase for the wallet.</source>
        <translation>የድሮውን የይለፍ-ሐረግ እና አዲሱን የይለፍ-ሐረግ ወደ ቢትኮይን ቦርሳዎ ያስገቡ::</translation>
    </message>
    <message>
        <source>IMPORTANT: Any previous backups you have made of your wallet file should be replaced with the newly generated, encrypted wallet file. For security reasons, previous backups of the unencrypted wallet file will become useless as soon as you start using the new, encrypted wallet.</source>
        <translation>አስፈላጊ: ከ ቦርሳ ፋይልዎ ያከናወኗቸው ቀደም ያሉ ምትኬዎች በአዲስ በተፈጠረ የማመስጠሪያ ፋይል ውስጥ መተካት አለባቸው. ለደህንነት ሲባል, አዲሱን የተመሰጠ የቦርሳ ፋይል መጠቀም ሲጀመሩ ወዲያውኑ ቀደም ሲል ያልተመሰጠሩ የቦርሳ ፋይል ቅጂዎች ዋጋ ቢስ ይሆናሉ::</translation>
    </message>
    <message>
        <source>Wallet encryption failed</source>
        <translation>የቦርሳ ማመስጠር አልተሳካም</translation>
    </message>
    <message>
        <source>Wallet encryption failed due to an internal error. Your wallet was not encrypted.</source>
        <translation>የቦርሳ ማመስጠር በውስጣዊ ስህተት ምክንያት አልተሳካም:: ቦርሳዎ አልተመሰጠረም::</translation>
    </message>
    <message>
        <source>The supplied passphrases do not match.</source>
        <translation>የተሰጡት የይለፍ-ሐረግዎች አይዛመዱም::</translation>
    </message>
    <message>
        <source>Wallet unlock failed</source>
        <translation>ቦርሳ መክፈት አልተሳካም</translation>
    </message>
    <message>
        <source>The passphrase entered for the wallet decryption was incorrect.</source>
        <translation>ቦርሳ ለመፍታት ያስገቡት የይለፍ-ሐረግ ትክክል አልነበረም::</translation>
    </message>
    <message>
        <source>Wallet decryption failed</source>
        <translation>ቦርሳ መፍታት አልተሳካም </translation>
    </message>
    <message>
        <source>Wallet passphrase was successfully changed.</source>
        <translation>የቦርሳ የይለፍ-ሐረግ በተሳካ ሁኔታ ተቀይሯል.</translation>
    </message>
    <message>
        <source>Warning: The Caps Lock key is on!</source>
        <translation>ማስጠንቀቂያ: የ "Caps Lock" ቁልፍ በርቷል!</translation>
    </message>
</context>
<context>
    <name>BanTableModel</name>
    <message>
        <source>IP/Netmask</source>
        <translation>አይፒ/ኔትማስክ  IP/Netmask</translation>
    </message>
    <message>
        <source>Banned Until</source>
        <translation>ታግደዋል እስከ</translation>
    </message>
</context>
<context>
    <name>BitcoinGUI</name>
    <message>
        <source>Sign &amp;message...</source>
        <translation>ምልክትና መልእክት...</translation>
    </message>
    <message>
        <source>Synchronizing with network...</source>
        <translation>ከኔትወርክ ጋራ በማመሳሰል ላይ ነው...</translation>
    </message>
    <message>
        <source>&amp;Overview</source>
        <translation>&amp;አጠቃላይ እይታ</translation>
    </message>
    <message>
        <source>Show general overview of wallet</source>
        <translation>የቦርሳ አጠቃላይ እይታ ኣሳይ</translation>
    </message>
    <message>
        <source>&amp;Transactions</source>
        <translation>&amp;ግብይቶች</translation>
    </message>
    <message>
        <source>Browse transaction history</source>
        <translation>የግብይት ታሪክ ያስሱ</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation>ውጣ</translation>
    </message>
    <message>
        <source>Quit application</source>
        <translation>አፕሊኬሽኑን አቁም</translation>
    </message>
    <message>
        <source>&amp;About %1</source>
        <translation>&amp;ስለ %1</translation>
    </message>
    <message>
        <source>Show information about %1</source>
        <translation>ስለ %1 መረጃ አሳይ</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>ስለ &amp;Qt</translation>
    </message>
    <message>
        <source>Show information about Qt</source>
        <translation>ስለ Qt መረጃ አሳይ</translation>
    </message>
    <message>
        <source>&amp;Options...</source>
        <translation>&amp;አማራጮች...</translation>
    </message>
    <message>
        <source>&amp;Encrypt Wallet...</source>
        <translation type="unfinished">&amp;የቢትኮይን ቦርሳውን አመስጥር...</translation>
    </message>
    <message>
        <source>Create Wallet...</source>
        <translation>ዋሌት ፍጠር</translation>
    </message>
    <message>
        <source>Create a new wallet</source>
        <translation>አዲስ ዋሌት ፍጠር</translation>
    </message>
    <message>
        <source>Wallet:</source>
        <translation>ዋሌት</translation>
    </message>
    <message>
        <source>&amp;Send</source>
        <translation>&amp;ላክ</translation>
    </message>
    <message>
        <source>&amp;Receive</source>
        <translation>&amp;ተቀበል</translation>
    </message>
    <message>
        <source>&amp;Show / Hide</source>
        <translation>&amp;አሳይ/ ደብቅ</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;ፋይል</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;ቅንብሮች</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;እርዳታ</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>ስህተት</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>ማሳስቢያ</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>መረጃ</translation>
    </message>
    <message>
        <source>&amp;Sending addresses</source>
        <translation type="unfinished">&amp;የመላኪያ አድራሻዎች</translation>
    </message>
    <message>
        <source>&amp;Receiving addresses</source>
        <translation type="unfinished">&amp;የመቀበያ አድራሻዎች</translation>
    </message>
    <message>
        <source>Open Wallet</source>
        <translation>ዋሌት ክፈት</translation>
    </message>
    <message>
        <source>Open a wallet</source>
        <translation>ዋሌት ክፈት</translation>
    </message>
    <message>
        <source>Close Wallet...</source>
        <translation>ዋሌት ዝጋ</translation>
    </message>
    <message>
        <source>Close wallet</source>
        <translation>ዋሌት ዝጋ</translation>
    </message>
    <message>
        <source>Minimize</source>
        <translation>አሳንስ</translation>
    </message>
    <message>
        <source>Zoom</source>
        <translation>እሳድግ</translation>
    </message>
    <message>
        <source>Error: %1</source>
        <translation>ስህተት፥ %1</translation>
    </message>
    <message>
        <source>Warning: %1</source>
        <translation>ማሳሰቢያ፥ %1</translation>
    </message>
    <message>
        <source>Date: %1
</source>
        <translation>ቀን፥ %1
</translation>
    </message>
    <message>
        <source>Amount: %1
</source>
        <translation>መጠን፥ %1
</translation>
    </message>
    <message>
        <source>Address: %1
</source>
        <translation>አድራሻ፥ %1
</translation>
    </message>
    </context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>Quantity:</source>
        <translation>ብዛት፥</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>መጠን፥</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation>ክፍያ፥</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>መጠን</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>ቀን</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation>መጠኑ ገልብጥ</translation>
    </message>
    <message>
        <source>&amp;Copy address</source>
        <translation type="unfinished">&amp;አድራሻ ቅዳ</translation>
    </message>
    <message>
        <source>Copy &amp;label</source>
        <translation>ቅዳ &amp;መለያ ስም</translation>
    </message>
    <message>
        <source>Copy &amp;amount</source>
        <translation type="unfinished">&amp;መጠኑ ገልብጥ</translation>
    </message>
    <message>
        <source>Copy fee</source>
        <translation>ክፍያው ቅዳ</translation>
    </message>
    <message>
        <source>yes</source>
        <translation>አዎ</translation>
    </message>
    <message>
        <source>no</source>
        <translation>አይ</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(መለያ ስም የለም)</translation>
    </message>
    </context>
<context>
    <name>CreateWalletActivity</name>
    </context>
<context>
    <name>CreateWalletDialog</name>
    <message>
        <source>Wallet</source>
        <translation>ዋሌት</translation>
    </message>
    <message>
        <source>Wallet Name</source>
        <translation>ዋሌት ስም</translation>
    </message>
    <message>
        <source>Encrypt Wallet</source>
        <translation>የቢትኮይን ቦርሳውን አመስጥር</translation>
    </message>
    <message>
        <source>Create</source>
        <translation>ፍጠር</translation>
    </message>
    </context>
<context>
    <name>EditAddressDialog</name>
    <message>
        <source>&amp;Label</source>
        <translation type="unfinished">&amp;መለያ ስም</translation>
    </message>
    <message>
        <source>&amp;Address</source>
        <translation type="unfinished">&amp;አድራሻ</translation>
    </message>
    </context>
<context>
    <name>FreespaceChecker</name>
    <message>
        <source>name</source>
        <translation>ስም</translation>
    </message>
    </context>
<context>
    <name>HelpMessageDialog</name>
    <message>
        <source>version</source>
        <translation>ስሪት</translation>
    </message>
    <message>
        <source>About %1</source>
        <translation>ስለ እኛ %1</translation>
    </message>
    </context>
<context>
    <name>Intro</name>
    <message>
        <source>Welcome</source>
        <translation>እንኳን ደህና መጣህ</translation>
    </message>
    <message>
        <source>Welcome to %1.</source>
        <translation>እንኳን  ወድ %1 በደህና መጣህ።</translation>
    </message>
    <message>
        <source>Bitcoin</source>
        <translation>ቢትኮይን</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>ስህተት</translation>
    </message>
    </context>
<context>
    <name>ModalOverlay</name>
    <message>
        <source>Form</source>
        <translation>ከ</translation>
    </message>
    <message>
        <source>Unknown...</source>
        <translation>የማይታወቅ...</translation>
    </message>
    <message>
        <source>Hide</source>
        <translation>ደብቅ</translation>
    </message>
    </context>
<context>
    <name>NetWatchLogModel</name>
    <message>
        <source>Address</source>
        <comment>NetWatch: Address header</comment>
        <translation>አድራሻ</translation>
    </message>
</context>
<context>
    <name>OpenURIDialog</name>
    </context>
<context>
    <name>OpenWalletActivity</name>
    <message>
        <source>default wallet</source>
        <translation>መደበኛ ዋሌት</translation>
    </message>
    <message>
        <source>Open Wallet</source>
        <extracomment>Title of window indicating the progress of opening of a wallet.</extracomment>
        <translation>ዋሌት ክፈት</translation>
    </message>
    </context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>Options</source>
        <translation type="unfinished">አማራጮች</translation>
    </message>
    <message>
        <source>W&amp;allet</source>
        <translation type="unfinished">&amp;ዋሌት</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>ስህተት</translation>
    </message>
    </context>
<context>
    <name>OverviewPage</name>
    <message>
        <source>Form</source>
        <translation>ከ</translation>
    </message>
    </context>
<context>
    <name>PSBTOperationsDialog</name>
    <message>
        <source>Close</source>
        <translation type="unfinished">ዝጋ</translation>
    </message>
    </context>
<context>
    <name>PairingPage</name>
    </context>
<context>
    <name>PaymentServer</name>
    </context>
<context>
    <name>PeerTableModel</name>
    </context>
<context>
    <name>QObject</name>
    <message>
        <source>Amount</source>
        <translation>መጠን</translation>
    </message>
    <message>
        <source>Error: %1</source>
        <translation>ስህተት፥ %1</translation>
    </message>
    </context>
<context>
    <name>QRImageWidget</name>
    </context>
<context>
    <name>RPCConsole</name>
    <message>
        <source>&amp;Information</source>
        <translation type="unfinished">&amp;መረጃ</translation>
    </message>
    <message>
        <source>Wallet: </source>
        <translation type="unfinished">ዋሌት </translation>
    </message>
    <message>
        <source>&amp;Copy address</source>
        <extracomment>Context menu action to copy the address of a peer</extracomment>
        <translation type="unfinished">&amp;አድራሻ ቅዳ</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation type="unfinished">የማይታወቅ</translation>
    </message>
    </context>
<context>
    <name>ReceiveCoinsDialog</name>
    <message>
        <source>&amp;Amount:</source>
        <translation type="unfinished">&amp;መጠን:</translation>
    </message>
    <message>
        <source>&amp;Label:</source>
        <translation type="unfinished">&amp;መለያ ስም:</translation>
    </message>
    <message>
        <source>&amp;Copy address</source>
        <translation type="unfinished">&amp;አድራሻ ቅዳ</translation>
    </message>
    <message>
        <source>Copy &amp;label</source>
        <translation>ቅዳ &amp;መለያ ስም</translation>
    </message>
    <message>
        <source>Copy &amp;amount</source>
        <translation type="unfinished">&amp;መጠኑ ገልብጥ</translation>
    </message>
    </context>
<context>
    <name>ReceiveRequestDialog</name>
    <message>
        <source>Address:</source>
        <translation type="unfinished">አድራሻ:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>መጠን፥</translation>
    </message>
    <message>
        <source>Label:</source>
        <translation type="unfinished">መለያ ስም:</translation>
    </message>
    <message>
        <source>Wallet:</source>
        <translation>ዋሌት</translation>
    </message>
    <message>
        <source>Copy &amp;Address</source>
        <translation type="unfinished">&amp;አድራሻ ቅዳ</translation>
    </message>
    </context>
<context>
    <name>RecentRequestsTableModel</name>
    <message>
        <source>Date</source>
        <translation>ቀን</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>መለያ ስም</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(መለያ ስም የለም)</translation>
    </message>
    </context>
<context>
    <name>SendCoinsDialog</name>
    <message>
        <source>Quantity:</source>
        <translation>ብዛት፥</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>መጠን፥</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation>ክፍያ፥</translation>
    </message>
    <message>
        <source>Choose...</source>
        <translation type="unfinished">ምረጥ...</translation>
    </message>
    <message>
        <source>Hide</source>
        <translation>ደብቅ</translation>
    </message>
    <message>
        <source>S&amp;end</source>
        <translation type="unfinished">&amp;ላክ</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation>መጠኑ ገልብጥ</translation>
    </message>
    <message>
        <source>Copy fee</source>
        <translation>ክፍያው ቅዳ</translation>
    </message>
    <message>
        <source>Send</source>
        <translation type="unfinished">ላክ</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(መለያ ስም የለም)</translation>
    </message>
</context>
<context>
    <name>SendCoinsEntry</name>
    <message>
        <source>A&amp;mount:</source>
        <translation type="unfinished">&amp;መጠን:</translation>
    </message>
    <message>
        <source>&amp;Label:</source>
        <translation type="unfinished">&amp;መለያ ስም:</translation>
    </message>
    </context>
<context>
    <name>ShutdownWindow</name>
    </context>
<context>
    <name>SignVerifyMessageDialog</name>
    </context>
<context>
    <name>TrafficGraphWidget</name>
    </context>
<context>
    <name>TransactionDesc</name>
    <message>
        <source>Date</source>
        <translation>ቀን</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>መጠን</translation>
    </message>
    </context>
<context>
    <name>TransactionDescDialog</name>
    </context>
<context>
    <name>TransactionTableModel</name>
    <message>
        <source>Date</source>
        <translation>ቀን</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>መለያ ስም</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(መለያ ስም የለም)</translation>
    </message>
    </context>
<context>
    <name>TransactionView</name>
    <message>
        <source>&amp;Copy address</source>
        <translation type="unfinished">&amp;አድራሻ ቅዳ</translation>
    </message>
    <message>
        <source>Copy &amp;label</source>
        <translation>ቅዳ &amp;መለያ ስም</translation>
    </message>
    <message>
        <source>Copy &amp;amount</source>
        <translation type="unfinished">&amp;መጠኑ ገልብጥ</translation>
    </message>
    <message>
        <source>Comma separated file (*.csv)</source>
        <translation>ኮማ ሴፓሬትድ ፋይል (*.csv)</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>ቀን</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>መለዮ</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>አድራሻ</translation>
    </message>
    <message>
        <source>Exporting Failed</source>
        <translation>መላክ አልተሳካም</translation>
    </message>
    </context>
<context>
    <name>UnitDisplayStatusBarControl</name>
    </context>
<context>
    <name>WalletController</name>
    <message>
        <source>Close wallet</source>
        <translation>ዋሌት ዝጋ</translation>
    </message>
    </context>
<context>
    <name>WalletFrame</name>
    <message>
        <source>Create a new wallet</source>
        <translation>አዲስ ዋሌት ፍጠር</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>ስህተት</translation>
    </message>
    </context>
<context>
    <name>WalletModel</name>
    <message>
        <source>default wallet</source>
        <translation>መደበኛ ዋሌት</translation>
    </message>
</context>
<context>
    <name>WalletView</name>
    <message>
        <source>&amp;Export</source>
        <translation>&amp;ላክ</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation>በአሁኑ ማውጫ ውስጥ ያለውን መረጃ ወደ አንድ ፋይል ላክ</translation>
    </message>
    </context>
<context>
    <name>bitcoin-core</name>
    <message>
        <source>Error</source>
        <translation>ስህተት</translation>
    </message>
    </context>
</TS>